@@ -248,10 +248,13 @@ class ROCv3():
             key = (reg[0], reg[1])
             self.transaction_logger.debug(f'Caching register {key}')
             cached_val = self.cache[key]
-            new_val = cached_val & (~reg[3]) | reg[2]
+            new_val = (cached_val & (~reg[3])) | reg[2]
             if new_val != cached_val:
+                self.transaction_logger.debug("Cache miss")
                 write_registers.append((reg[0], reg[1], new_val))
                 self.cache[key] = new_val
+            else:
+                self.transaction_logger.debug("Cache hit")
         return write_registers
 
     def configure(self, configuration: dict, readback=False):
