@@ -117,16 +117,40 @@ def test_translator(config, registers, patched_io):
     assert roc_s0._translate(config) == registers
 
 
-def test_cache(patched_io):
-    write = [
-            (112, 5, 200, 255), (113, 5, 0, 255),
-            (114, 5, 0, 255), (115, 5, 0, 15)]
-    cached_write = [(112, 5, 200), (113, 5, 0), (114, 5, 0), (115, 5, 0)]
+@pytest.mark.parametrize(
+        "first_write, first_output, second_write, second_output",
+        [
+         ([
+           (112, 5, 200, 255), (113, 5, 0, 255),
+           (114, 5, 0, 255), (115, 5, 0, 15)
+           ],
+          [(112, 5, 200), (113, 5, 0), (114, 5, 0), (115, 5, 0)],
+          [
+           (112, 5, 200, 255), (113, 5, 0, 255),
+           (114, 5, 0, 255), (115, 5, 0, 15)
+           ],
+          []
+          ),
+         ([
+           (112, 5, 200, 255), (113, 5, 0, 255),
+           (114, 5, 0, 255), (115, 5, 0, 15)
+           ],
+          [(112, 5, 200), (113, 5, 0), (114, 5, 0), (115, 5, 0)],
+          [
+           (112, 5, 200, 255), (113, 5, 0, 255),
+           (114, 5, 0, 255), (115, 5, 0, 15)
+           ],
+          []
+          )
+         ]
+)
+def test_cache(first_write, first_output, second_write,
+               second_output, patched_io):
     roc_s0 = ROCv3(name='roc_s0', transport=None, base_address=None,
                    reset_pin=hexactrl_io.Xil_gpio('that', 'rst', 'output'),
                    path_to_file='regmaps/HGCROC3_I2C_params_regmap.csv')
-    assert roc_s0._cache(write) == cached_write
-    assert roc_s0._cache(write) == []
+    assert roc_s0._cache(first_write) == first_output
+    assert roc_s0._cache(second_write) == second_output
 
 
 @pytest.mark.parametrize(
